@@ -43,7 +43,7 @@ at::Tensor torch_get_cell(at::Tensor points, const float xmin, const float xmax,
 
 at::Tensor torch_get_velocity(at::Tensor points, at::Tensor theta, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
         
     // Do input checking
     CHECK_INPUT(points);
@@ -66,7 +66,7 @@ at::Tensor torch_get_velocity(at::Tensor points, at::Tensor theta, at::Tensor Bt
 
 at::Tensor torch_derivative_velocity_dtheta(at::Tensor points, at::Tensor theta, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(1), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(1), points.size(0)}).contiguous() : points.contiguous();
         
     // Do input checking
     CHECK_INPUT(points);
@@ -87,7 +87,7 @@ at::Tensor torch_derivative_velocity_dtheta(at::Tensor points, at::Tensor theta,
 
 at::Tensor torch_derivative_velocity_dx(at::Tensor points, at::Tensor theta, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
         
     // Do input checking
     CHECK_INPUT(points);
@@ -113,7 +113,7 @@ at::Tensor torch_derivative_velocity_dx(at::Tensor points, at::Tensor theta, at:
 
 at::Tensor torch_integrate_numeric(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
         
     // Do input checking
     CHECK_INPUT(points);
@@ -136,7 +136,7 @@ at::Tensor torch_integrate_numeric(at::Tensor points, at::Tensor theta, const fl
 
 at::Tensor torch_integrate_closed_form(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
         
     // Do input checking
     CHECK_INPUT(points);
@@ -161,7 +161,7 @@ at::Tensor torch_integrate_closed_form(at::Tensor points, at::Tensor theta, cons
 
 at::Tensor torch_derivative_numeric(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10, const float h=1e-3){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -191,7 +191,7 @@ at::Tensor torch_derivative_numeric(at::Tensor points, at::Tensor theta, const f
 
 at::Tensor torch_derivative_closed_form(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -218,7 +218,7 @@ at::Tensor torch_derivative_closed_form(at::Tensor points, at::Tensor theta, con
 
 at::Tensor torch_integrate_closed_form_trace(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -242,7 +242,7 @@ at::Tensor torch_integrate_closed_form_trace(at::Tensor points, at::Tensor theta
 
 at::Tensor torch_derivative_closed_form_trace(at::Tensor output, at::Tensor points, at::Tensor theta, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(output);
@@ -268,7 +268,7 @@ at::Tensor torch_derivative_closed_form_trace(at::Tensor output, at::Tensor poin
 
 at::Tensor torch_derivative_numeric_trace(at::Tensor phi_1, at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10, const float h=1e-3){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(phi_1);
@@ -335,7 +335,7 @@ at::Tensor torch_interpolate_grid_backward(at::Tensor grad_prev, at::Tensor poin
 
 at::Tensor torch_derivative_space_closed_form(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -358,7 +358,7 @@ at::Tensor torch_derivative_space_closed_form(at::Tensor points, at::Tensor thet
 
 at::Tensor torch_derivative_space_closed_form_dtheta(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -382,7 +382,7 @@ at::Tensor torch_derivative_space_closed_form_dtheta(at::Tensor points, at::Tens
 
 at::Tensor torch_derivative_space_closed_form_dx(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -406,7 +406,7 @@ at::Tensor torch_derivative_space_closed_form_dx(at::Tensor points, at::Tensor t
 
 at::Tensor torch_derivative_space_numeric(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10, const float h=1e-3){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
@@ -431,7 +431,7 @@ at::Tensor torch_derivative_space_numeric(at::Tensor points, at::Tensor theta, c
 
 at::Tensor torch_derivative_space_numeric_dtheta(at::Tensor phi_1, at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10, const float h=1e-3){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(phi_1);
@@ -459,7 +459,7 @@ at::Tensor torch_derivative_space_numeric_dtheta(at::Tensor phi_1, at::Tensor po
 
 at::Tensor torch_derivative_space_numeric_dx(at::Tensor points, at::Tensor theta, const float t, at::Tensor Bt, const float xmin, const float xmax, const int nc, const int nSteps1=10, const int nSteps2=10, const float h=1e-3){
     // Batch grid
-    if(points.dim() == 1) points = torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous();
+    points = (points.dim() == 1) ? torch::broadcast_to(points, {theta.size(0), points.size(0)}).contiguous() : points.contiguous();
     
     // Do input checking
     CHECK_INPUT(points);
